@@ -1,4 +1,7 @@
 import copy
+from typing import Tuple
+
+import torch
 
 from ..containers import KeyEnforcer, MultipleContainers, Optimizers
 from ..hooks import ADDAHook
@@ -9,23 +12,45 @@ from .utils import default_optimizer_tuple, with_opt
 
 class ADDA(BaseAdapter):
     """
-    Wraps [ADDAHook][pytorch_adapt.hooks.adda].
+    Extends [BaseAdapter][pytorch_adapt.adapters.BaseAdapter]
+    and wraps [ADDAHook][pytorch_adapt.hooks.ADDAHook].
+
+    |Container|Required keys|
+    |---|---|
+    |models|```["G", "C", "D"]```|
+    |optimizers|```["D", "T"]```|
+
+    The target model ("T") is created during initialization by deep-copying the G model.
     """
 
     hook_cls = ADDAHook
 
-    def inference_default(self, x, domain):
+    def inference_default(self, x, domain) -> Tuple[torch.Tensor, torch.Tensor]:
+        """
+        Arguments:
+            x: The input to the model
+            domain: If 0, then ```features = G(x)```
+                Otherwise ```features = T(x)```.
+        Returns:
+            Features and logits
+        """
         domain = check_domain(self, domain)
         fe = "G" if domain == 0 else "T"
         features = self.models[fe](x)
         logits = self.models["C"](features)
         return features, logits
 
-    def get_default_containers(self):
+    def get_default_containers(self) -> MultipleContainers:
+        """
+        Returns:
+            The default set of containers. This
+            will create an Adam optimizer with lr 0.0001 for
+            the T and D models.
+        """
         optimizers = Optimizers(default_optimizer_tuple(), keys=["T", "D"])
         return MultipleContainers(optimizers=optimizers)
 
-    def get_key_enforcer(self):
+    def get_key_enforcer(self) -> KeyEnforcer:
         return KeyEnforcer(
             models=["G", "C", "D", "T"],
             optimizers=["D", "T"],
