@@ -3,7 +3,7 @@ from .combined_source_and_target import CombinedSourceAndTargetDataset
 from .concat_dataset import ConcatDataset
 from .dataloader_creator import DataloaderCreator
 from .domainnet import DomainNet, DomainNet126, DomainNet126Full
-from .getters import get_mnist_mnistm
+from .getters import get_mnist_mnistm, get_office31, get_officehome
 from .mnistm import MNISTM
 from .office31 import Office31, Office31Full
 from .officehome import OfficeHome, OfficeHomeFull
